@@ -1,4 +1,5 @@
 package Email::FolderType::Ezmlm;
+use strict;
 
 =head1 NAME
 
@@ -6,7 +7,10 @@ Email::FolderType::Ezmlm - class to help Email::FolderType recognise ezmlm archi
 
 =cut
 
-sub match { my $folder = shift; return ($folder =~ m{//$}  || -d "$folder/archive"); }
+sub match {
+  my $folder = shift;
+  return ($folder =~ m{//$}  || -d "$folder/archive");
+}
 
 
 1;
